/*****************************************************************************
 *   main.c:  main C entry file for Philips LPC214x Family Microprocessors
 *
 *   Copyright(C) 2006, Philips Semiconductor
 *   All rights reserved.
 *
 *   History
 *   2005.10.01  ver 1.00    Prelimnary version, first Release
 *
******************************************************************************/

#include "lpc214x.h"
#include "armVIC.h"
#include "system.h"
#include "mam.h"
#include "pll.h"

#define LED (1 << 30)

MEMORY void switchLED (void);

MEMORY void switchLED (void)
{
   volatile static char flip;
   if (flip) IOCLR0 = LED; else IOSET0 = LED;
   flip = !flip;
}

MEMORY void __attribute__ ((interrupt("IRQ"))) IRQ_Timer0 (void);

MEMORY void __attribute__ ((interrupt("IRQ"))) IRQ_Timer0 (void)
{
    switchLED();           // Methode zum toggeln der LED
    T0IR = 0x01;           // Rcksetzen des Timerinterrupts
    VICVectAddr = 0;       // Acknowledge Interrupt
}


MEMORY void wait (void);

MEMORY void wait (void)
{
  for (;;);
}



/*****************************************************************************
**   Main Function  main()
*****************************************************************************/

int main (void)
{	 
//   target_init();  // PLL und MAM
PINSEL0 = 0x00000000;
PINSEL1 = 0x00000000;
PINSEL2 = 0x00000000;

mam_initialisierung();
pll_initialisierung();

   IODIR0 = LED;
   T0PR = 0x0;
  //Prescale Register (berlaufwert) 0 => pclk = 58.9824MHz = Timer-Clock

  T0MCR = 0x3;
  //TimerCounter = MatchRegister0 => Interrupt 0 + Timer Counter Reset

//  T0MR0=58982400;
  T0MR0 = PCLK / (0.5 * 2);
  //MatchRegister0 entspricht 0.5s

  T0TCR=0x2;
  //Prescale-Counter und Timer-Counter werden geresettet

  T0TCR=0x1;
  //Prescale-Counter und Timer-Counter werden gestartet

VICVectAddr0 = (unsigned long) IRQ_Timer0;     // set interrupt vector in 0
VICVectCntl0 = 0x20 | 4;                   // use it for Timer0 (4) Interrupt
VICIntEnable = VICIntEnable | (1 << 4);    // Enable Timer0 Interrupt

//  irq_init();
//  irq_install(TIMER0_INT, IRQ_Timer0);
//  irq_enableIRQ();
enableIRQ();
  
wait();

return 0;	
}

/*****************************************************************************
**                            End Of File
******************************************************************************/
